@@ -23,7 +23,7 @@ import os
 import os.path
 import glob
 
-__version__ = "1.0"
+__version__ = "1.1"
 
 class MSCLexer(object):
     """Lexer class"""
@@ -134,6 +134,7 @@ class MSCLexer(object):
             "SecAuditLogType",
             "SecAuditLogFormat",
             "SecAuditLog",
+            "SecAuditLogStorageDir",
             "SecArgumentSeparator",
             "SecCookieFormat",
             "SecStatusEngine",
@@ -443,12 +444,14 @@ class MSCLexer(object):
     def t_STINCLUDEDIRECTIVE_T_INCLUDE_DIRECTIVE_ARGUMENT(self, t):
         r'[0-9A-Za-z_\/\.\-\*\:]+'
         #self.parse_seclang_config(t)
+        t.lexer.begin('INITIAL')
         return t
 
     def t_STINCLUDEDIRECTIVE_T_INCLUDE_DIRECTIVE_ARGUMENT_QUOTED(self, t):
         r'"[0-9A-Za-z_\/\.\-\*\:]+"'
         #self.parse_seclang_config(t)
         t.value = t.value.strip("\"")
+        t.lexer.begin('INITIAL')
         return t
 
 # END Handle include directive
@@ -468,12 +471,12 @@ class MSCLexer(object):
 
 # END Simple configuration directives
 
+# Apache Locaition directive
+
     def t_INITIAL_T_APACHE_LOCATION_DIRECTIVE(self, t):
         r'<(/|)Location.*>'
         return t
 
-# Apache Locaition directive
-
 # END Apache Locaition directive
 
 # Secrule VARIABLE
@@ -574,7 +577,7 @@ class MSCLexer(object):
         return t
 
     def t_STSECRULEACTIONARGUMENTQUOTES_T_SECRULE_ACTION_ARGUMENT(self, t):
-        r'((?:[^\\\']|\\.)+)'
+        r'((?:[^\\\']|\\(.|\s))+)'
         self.eolcount = len(t.value.split("\n"))-1
         t.lexer.lineno += self.eolcount
         return t
